# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_parties.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_parties.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bsteammessages_parties.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"@\n\x1a\x43Parties_JoinParty_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x11\n\tbeacon_id\x18\x02 \x01(\x04\"H\n\x1b\x43Parties_JoinParty_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x16\n\x0e\x63onnect_string\x18\x02 \x01(\t\"E\n\x17\x43Parties_BeaconLocation\x12\x15\n\rlocation_type\x18\x01 \x01(\r\x12\x13\n\x0blocation_id\x18\x02 \x01(\x04\"\x9d\x01\n\x1d\x43Parties_CreateBeacon_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x16\n\x0enum_open_slots\x18\x02 \x01(\r\x12+\n\tlocations\x18\x03 \x03(\x0b\x32\x18.CParties_BeaconLocation\x12\x16\n\x0e\x63onnect_string\x18\x04 \x01(\t\x12\x10\n\x08metadata\x18\x05 \x01(\t\"3\n\x1e\x43Parties_CreateBeacon_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"R\n\'CParties_OnReservationCompleted_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\"=\n(CParties_OnReservationCompleted_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"M\n\"CParties_CancelReservation_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\"8\n#CParties_CancelReservation_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"P\n#CParties_ChangeNumOpenSlots_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x16\n\x0enum_open_slots\x18\x02 \x01(\r\"9\n$CParties_ChangeNumOpenSlots_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"3\n\x1e\x43Parties_DestroyBeacon_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"4\n\x1f\x43Parties_DestroyBeacon_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x32\xd9\x07\n\x07Parties\x12\xb9\x01\n\tJoinParty\x12\x1b.CParties_JoinParty_Request\x1a\x1c.CParties_JoinParty_Response\"q\x82\xb5\x18mRequest to join a Party via the given Beacon ID. If successful, will be given the necessary \'connect\' string.\x12\x85\x01\n\x0c\x43reateBeacon\x12\x1e.CParties_CreateBeacon_Request\x1a\x1f.CParties_CreateBeacon_Response\"4\x82\xb5\x18\x30\x43reate a Beacon to attract people to your Party.\x12\xb7\x01\n\x16OnReservationCompleted\x12(.CParties_OnReservationCompleted_Request\x1a).CParties_OnReservationCompleted_Response\"H\x82\xb5\x18\x44Notify Steam that a user with a reservation has successfully joined.\x12\xbe\x01\n\x11\x43\x61ncelReservation\x12#.CParties_CancelReservation_Request\x1a$.CParties_CancelReservation_Response\"^\x82\xb5\x18ZNotify Steam that a user with a reservation either never showed up, or has left the party.\x12\x86\x01\n\x12\x43hangeNumOpenSlots\x12$.CParties_ChangeNumOpenSlots_Request\x1a%.CParties_ChangeNumOpenSlots_Response\"#\x82\xb5\x18\x1f\x43hange the number of open slots\x12j\n\rDestroyBeacon\x12\x1f.CParties_DestroyBeacon_Request\x1a .CParties_DestroyBeacon_Response\"\x16\x82\xb5\x18\x12\x44\x65lete the Beacon.\x1a\x1a\x82\xb5\x18\x16Party-related servicesB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CPARTIES_JOINPARTY_REQUEST = _descriptor.Descriptor(
  name='CParties_JoinParty_Request',
  full_name='CParties_JoinParty_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CParties_JoinParty_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_JoinParty_Request.beacon_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=155,
)


_CPARTIES_JOINPARTY_RESPONSE = _descriptor.Descriptor(
  name='CParties_JoinParty_Response',
  full_name='CParties_JoinParty_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_JoinParty_Response.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_string', full_name='CParties_JoinParty_Response.connect_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=229,
)


_CPARTIES_BEACONLOCATION = _descriptor.Descriptor(
  name='CParties_BeaconLocation',
  full_name='CParties_BeaconLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location_type', full_name='CParties_BeaconLocation.location_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location_id', full_name='CParties_BeaconLocation.location_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=300,
)


_CPARTIES_CREATEBEACON_REQUEST = _descriptor.Descriptor(
  name='CParties_CreateBeacon_Request',
  full_name='CParties_CreateBeacon_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CParties_CreateBeacon_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_open_slots', full_name='CParties_CreateBeacon_Request.num_open_slots', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locations', full_name='CParties_CreateBeacon_Request.locations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_string', full_name='CParties_CreateBeacon_Request.connect_string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CParties_CreateBeacon_Request.metadata', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=460,
)


_CPARTIES_CREATEBEACON_RESPONSE = _descriptor.Descriptor(
  name='CParties_CreateBeacon_Response',
  full_name='CParties_CreateBeacon_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_CreateBeacon_Response.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=513,
)


_CPARTIES_ONRESERVATIONCOMPLETED_REQUEST = _descriptor.Descriptor(
  name='CParties_OnReservationCompleted_Request',
  full_name='CParties_OnReservationCompleted_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_OnReservationCompleted_Request.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CParties_OnReservationCompleted_Request.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=515,
  serialized_end=597,
)


_CPARTIES_ONRESERVATIONCOMPLETED_RESPONSE = _descriptor.Descriptor(
  name='CParties_OnReservationCompleted_Response',
  full_name='CParties_OnReservationCompleted_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_OnReservationCompleted_Response.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=660,
)


_CPARTIES_CANCELRESERVATION_REQUEST = _descriptor.Descriptor(
  name='CParties_CancelReservation_Request',
  full_name='CParties_CancelReservation_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_CancelReservation_Request.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CParties_CancelReservation_Request.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=662,
  serialized_end=739,
)


_CPARTIES_CANCELRESERVATION_RESPONSE = _descriptor.Descriptor(
  name='CParties_CancelReservation_Response',
  full_name='CParties_CancelReservation_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_CancelReservation_Response.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=797,
)


_CPARTIES_CHANGENUMOPENSLOTS_REQUEST = _descriptor.Descriptor(
  name='CParties_ChangeNumOpenSlots_Request',
  full_name='CParties_ChangeNumOpenSlots_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_ChangeNumOpenSlots_Request.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_open_slots', full_name='CParties_ChangeNumOpenSlots_Request.num_open_slots', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=799,
  serialized_end=879,
)


_CPARTIES_CHANGENUMOPENSLOTS_RESPONSE = _descriptor.Descriptor(
  name='CParties_ChangeNumOpenSlots_Response',
  full_name='CParties_ChangeNumOpenSlots_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_ChangeNumOpenSlots_Response.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=881,
  serialized_end=938,
)


_CPARTIES_DESTROYBEACON_REQUEST = _descriptor.Descriptor(
  name='CParties_DestroyBeacon_Request',
  full_name='CParties_DestroyBeacon_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_DestroyBeacon_Request.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=940,
  serialized_end=991,
)


_CPARTIES_DESTROYBEACON_RESPONSE = _descriptor.Descriptor(
  name='CParties_DestroyBeacon_Response',
  full_name='CParties_DestroyBeacon_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_DestroyBeacon_Response.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=993,
  serialized_end=1045,
)

_CPARTIES_CREATEBEACON_REQUEST.fields_by_name['locations'].message_type = _CPARTIES_BEACONLOCATION
DESCRIPTOR.message_types_by_name['CParties_JoinParty_Request'] = _CPARTIES_JOINPARTY_REQUEST
DESCRIPTOR.message_types_by_name['CParties_JoinParty_Response'] = _CPARTIES_JOINPARTY_RESPONSE
DESCRIPTOR.message_types_by_name['CParties_BeaconLocation'] = _CPARTIES_BEACONLOCATION
DESCRIPTOR.message_types_by_name['CParties_CreateBeacon_Request'] = _CPARTIES_CREATEBEACON_REQUEST
DESCRIPTOR.message_types_by_name['CParties_CreateBeacon_Response'] = _CPARTIES_CREATEBEACON_RESPONSE
DESCRIPTOR.message_types_by_name['CParties_OnReservationCompleted_Request'] = _CPARTIES_ONRESERVATIONCOMPLETED_REQUEST
DESCRIPTOR.message_types_by_name['CParties_OnReservationCompleted_Response'] = _CPARTIES_ONRESERVATIONCOMPLETED_RESPONSE
DESCRIPTOR.message_types_by_name['CParties_CancelReservation_Request'] = _CPARTIES_CANCELRESERVATION_REQUEST
DESCRIPTOR.message_types_by_name['CParties_CancelReservation_Response'] = _CPARTIES_CANCELRESERVATION_RESPONSE
DESCRIPTOR.message_types_by_name['CParties_ChangeNumOpenSlots_Request'] = _CPARTIES_CHANGENUMOPENSLOTS_REQUEST
DESCRIPTOR.message_types_by_name['CParties_ChangeNumOpenSlots_Response'] = _CPARTIES_CHANGENUMOPENSLOTS_RESPONSE
DESCRIPTOR.message_types_by_name['CParties_DestroyBeacon_Request'] = _CPARTIES_DESTROYBEACON_REQUEST
DESCRIPTOR.message_types_by_name['CParties_DestroyBeacon_Response'] = _CPARTIES_DESTROYBEACON_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CParties_JoinParty_Request = _reflection.GeneratedProtocolMessageType('CParties_JoinParty_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_JOINPARTY_REQUEST,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_JoinParty_Request)
  })
_sym_db.RegisterMessage(CParties_JoinParty_Request)

CParties_JoinParty_Response = _reflection.GeneratedProtocolMessageType('CParties_JoinParty_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_JOINPARTY_RESPONSE,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_JoinParty_Response)
  })
_sym_db.RegisterMessage(CParties_JoinParty_Response)

CParties_BeaconLocation = _reflection.GeneratedProtocolMessageType('CParties_BeaconLocation', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_BEACONLOCATION,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_BeaconLocation)
  })
_sym_db.RegisterMessage(CParties_BeaconLocation)

CParties_CreateBeacon_Request = _reflection.GeneratedProtocolMessageType('CParties_CreateBeacon_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_CREATEBEACON_REQUEST,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_CreateBeacon_Request)
  })
_sym_db.RegisterMessage(CParties_CreateBeacon_Request)

CParties_CreateBeacon_Response = _reflection.GeneratedProtocolMessageType('CParties_CreateBeacon_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_CREATEBEACON_RESPONSE,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_CreateBeacon_Response)
  })
_sym_db.RegisterMessage(CParties_CreateBeacon_Response)

CParties_OnReservationCompleted_Request = _reflection.GeneratedProtocolMessageType('CParties_OnReservationCompleted_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_ONRESERVATIONCOMPLETED_REQUEST,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_OnReservationCompleted_Request)
  })
_sym_db.RegisterMessage(CParties_OnReservationCompleted_Request)

CParties_OnReservationCompleted_Response = _reflection.GeneratedProtocolMessageType('CParties_OnReservationCompleted_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_ONRESERVATIONCOMPLETED_RESPONSE,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_OnReservationCompleted_Response)
  })
_sym_db.RegisterMessage(CParties_OnReservationCompleted_Response)

CParties_CancelReservation_Request = _reflection.GeneratedProtocolMessageType('CParties_CancelReservation_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_CANCELRESERVATION_REQUEST,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_CancelReservation_Request)
  })
_sym_db.RegisterMessage(CParties_CancelReservation_Request)

CParties_CancelReservation_Response = _reflection.GeneratedProtocolMessageType('CParties_CancelReservation_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_CANCELRESERVATION_RESPONSE,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_CancelReservation_Response)
  })
_sym_db.RegisterMessage(CParties_CancelReservation_Response)

CParties_ChangeNumOpenSlots_Request = _reflection.GeneratedProtocolMessageType('CParties_ChangeNumOpenSlots_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_CHANGENUMOPENSLOTS_REQUEST,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_ChangeNumOpenSlots_Request)
  })
_sym_db.RegisterMessage(CParties_ChangeNumOpenSlots_Request)

CParties_ChangeNumOpenSlots_Response = _reflection.GeneratedProtocolMessageType('CParties_ChangeNumOpenSlots_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_CHANGENUMOPENSLOTS_RESPONSE,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_ChangeNumOpenSlots_Response)
  })
_sym_db.RegisterMessage(CParties_ChangeNumOpenSlots_Response)

CParties_DestroyBeacon_Request = _reflection.GeneratedProtocolMessageType('CParties_DestroyBeacon_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_DESTROYBEACON_REQUEST,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_DestroyBeacon_Request)
  })
_sym_db.RegisterMessage(CParties_DestroyBeacon_Request)

CParties_DestroyBeacon_Response = _reflection.GeneratedProtocolMessageType('CParties_DestroyBeacon_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_DESTROYBEACON_RESPONSE,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_DestroyBeacon_Response)
  })
_sym_db.RegisterMessage(CParties_DestroyBeacon_Response)


DESCRIPTOR._options = None

_PARTIES = _descriptor.ServiceDescriptor(
  name='Parties',
  full_name='Parties',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\026Party-related services',
  create_key=_descriptor._internal_create_key,
  serialized_start=1048,
  serialized_end=2033,
  methods=[
  _descriptor.MethodDescriptor(
    name='JoinParty',
    full_name='Parties.JoinParty',
    index=0,
    containing_service=None,
    input_type=_CPARTIES_JOINPARTY_REQUEST,
    output_type=_CPARTIES_JOINPARTY_RESPONSE,
    serialized_options=b'\202\265\030mRequest to join a Party via the given Beacon ID. If successful, will be given the necessary \'connect\' string.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateBeacon',
    full_name='Parties.CreateBeacon',
    index=1,
    containing_service=None,
    input_type=_CPARTIES_CREATEBEACON_REQUEST,
    output_type=_CPARTIES_CREATEBEACON_RESPONSE,
    serialized_options=b'\202\265\0300Create a Beacon to attract people to your Party.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnReservationCompleted',
    full_name='Parties.OnReservationCompleted',
    index=2,
    containing_service=None,
    input_type=_CPARTIES_ONRESERVATIONCOMPLETED_REQUEST,
    output_type=_CPARTIES_ONRESERVATIONCOMPLETED_RESPONSE,
    serialized_options=b'\202\265\030DNotify Steam that a user with a reservation has successfully joined.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelReservation',
    full_name='Parties.CancelReservation',
    index=3,
    containing_service=None,
    input_type=_CPARTIES_CANCELRESERVATION_REQUEST,
    output_type=_CPARTIES_CANCELRESERVATION_RESPONSE,
    serialized_options=b'\202\265\030ZNotify Steam that a user with a reservation either never showed up, or has left the party.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChangeNumOpenSlots',
    full_name='Parties.ChangeNumOpenSlots',
    index=4,
    containing_service=None,
    input_type=_CPARTIES_CHANGENUMOPENSLOTS_REQUEST,
    output_type=_CPARTIES_CHANGENUMOPENSLOTS_RESPONSE,
    serialized_options=b'\202\265\030\037Change the number of open slots',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DestroyBeacon',
    full_name='Parties.DestroyBeacon',
    index=5,
    containing_service=None,
    input_type=_CPARTIES_DESTROYBEACON_REQUEST,
    output_type=_CPARTIES_DESTROYBEACON_RESPONSE,
    serialized_options=b'\202\265\030\022Delete the Beacon.',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PARTIES)

DESCRIPTOR.services_by_name['Parties'] = _PARTIES

Parties = service_reflection.GeneratedServiceType('Parties', (_service.Service,), dict(
  DESCRIPTOR = _PARTIES,
  __module__ = 'steammessages_parties_pb2'
  ))

Parties_Stub = service_reflection.GeneratedServiceStubType('Parties_Stub', (Parties,), dict(
  DESCRIPTOR = _PARTIES,
  __module__ = 'steammessages_parties_pb2'
  ))


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_datapublisher.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_datapublisher.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!steammessages_datapublisher.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\xfd\x03\n9CDataPublisher_ClientContentCorruptionReport_Notification\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x64\x65potid\x18\x02 \x01(\r\x12\x39\n\x0f\x64ownload_source\x18\x03 \x01(\tB \x82\xb5\x18\x1chost name of download source\x12.\n\x08objectid\x18\x04 \x01(\tB\x1c\x82\xb5\x18\x18\x43hunk SHA or Manifest ID\x12\"\n\x06\x63\x65llid\x18\x05 \x01(\rB\x12\x82\xb5\x18\x0e\x43lient Cell ID\x12>\n\x0bis_manifest\x18\x06 \x01(\x08\x42)\x82\xb5\x18%The object is a manifest, not a chunk\x12-\n\x0bobject_size\x18\x07 \x01(\x04\x42\x18\x82\xb5\x18\x14object size in bytes\x12\x37\n\x0f\x63orruption_type\x18\x08 \x01(\rB\x1e\x82\xb5\x18\x1aSee EContentCorruptionType\x12-\n\nused_https\x18\t \x01(\x08\x42\x19\x82\xb5\x18\x15the request was HTTPS\x12:\n\x11oc_proxy_detected\x18\n \x01(\x08\x42\x1f\x82\xb5\x18\x1b\x64\x65tected an OpenCache proxy\"\xd0\x04\n.CDataPublisher_ClientUpdateAppJob_Notification\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tdepot_ids\x18\x02 \x03(\r\x12\x11\n\tapp_state\x18\x03 \x01(\r\x12\x15\n\rjob_app_error\x18\x04 \x01(\r\x12\x15\n\rerror_details\x18\x05 \x01(\t\x12\x14\n\x0cjob_duration\x18\x06 \x01(\r\x12\x1f\n\x17\x66iles_validation_failed\x18\x07 \x01(\r\x12\x1c\n\x14job_bytes_downloaded\x18\x08 \x01(\x04\x12\x18\n\x10job_bytes_staged\x18\t \x01(\x04\x12\x16\n\x0e\x62ytes_comitted\x18\n \x01(\x04\x12\x17\n\x0fstart_app_state\x18\x0b \x01(\r\x12\x18\n\x10stats_machine_id\x18\x0c \x01(\x06\x12\x13\n\x0b\x62ranch_name\x18\r \x01(\t\x12\x1e\n\x16total_bytes_downloaded\x18\x0e \x01(\x04\x12\x1a\n\x12total_bytes_staged\x18\x0f \x01(\x04\x12\x1c\n\x14total_bytes_restored\x18\x10 \x01(\x04\x12\x13\n\x0bis_borrowed\x18\x11 \x01(\x08\x12\x17\n\x0fis_free_weekend\x18\x12 \x01(\x08\x12\x1a\n\x12total_bytes_legacy\x18\x13 \x01(\x04\x12\x1b\n\x13total_bytes_patched\x18\x14 \x01(\x04\x12\x19\n\x11total_bytes_saved\x18\x15 \x01(\x04\x12\x0f\n\x07\x63\x65ll_id\x18\x16 \x01(\r\"c\n(CValveHWSurvey_GetSurveySchedule_Request\x12\x17\n\x0fsurveydatetoken\x18\x01 \x01(\t\x12\x1e\n\x16surveydatetokenversion\x18\x02 \x01(\x06\"d\n)CValveHWSurvey_GetSurveySchedule_Response\x12\x17\n\x0fsurveydatetoken\x18\x01 \x01(\r\x12\x1e\n\x16surveydatetokenversion\x18\x02 \x01(\x06\x32\xfc\x01\n\rDataPublisher\x12h\n\x1d\x43lientContentCorruptionReport\x12:.CDataPublisher_ClientContentCorruptionReport_Notification\x1a\x0b.NoResponse\x12X\n\x18\x43lientUpdateAppJobReport\x12/.CDataPublisher_ClientUpdateAppJob_Notification\x1a\x0b.NoResponse\x1a\'\x82\xb5\x18#Data Publisher (DP) server services2\xac\x01\n\rValveHWSurvey\x12\x87\x01\n\x11GetSurveySchedule\x12).CValveHWSurvey_GetSurveySchedule_Request\x1a*.CValveHWSurvey_GetSurveySchedule_Response\"\x1b\x82\xb5\x18\x17Should I run the survey\x1a\x11\x82\xb5\x18\rValveHWSurveyB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION = _descriptor.Descriptor(
  name='CDataPublisher_ClientContentCorruptionReport_Notification',
  full_name='CDataPublisher_ClientContentCorruptionReport_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depotid', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.depotid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='download_source', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.download_source', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034host name of download source', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='objectid', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.objectid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030Chunk SHA or Manifest ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cellid', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.cellid', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\016Client Cell ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_manifest', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.is_manifest', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%The object is a manifest, not a chunk', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_size', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.object_size', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024object size in bytes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='corruption_type', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.corruption_type', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032See EContentCorruptionType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='used_https', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.used_https', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\025the request was HTTPS', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oc_proxy_detected', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.oc_proxy_detected', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\033detected an OpenCache proxy', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=607,
)


_CDATAPUBLISHER_CLIENTUPDATEAPPJOB_NOTIFICATION = _descriptor.Descriptor(
  name='CDataPublisher_ClientUpdateAppJob_Notification',
  full_name='CDataPublisher_ClientUpdateAppJob_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CDataPublisher_ClientUpdateAppJob_Notification.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depot_ids', full_name='CDataPublisher_ClientUpdateAppJob_Notification.depot_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_state', full_name='CDataPublisher_ClientUpdateAppJob_Notification.app_state', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_app_error', full_name='CDataPublisher_ClientUpdateAppJob_Notification.job_app_error', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_details', full_name='CDataPublisher_ClientUpdateAppJob_Notification.error_details', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_duration', full_name='CDataPublisher_ClientUpdateAppJob_Notification.job_duration', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='files_validation_failed', full_name='CDataPublisher_ClientUpdateAppJob_Notification.files_validation_failed', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_bytes_downloaded', full_name='CDataPublisher_ClientUpdateAppJob_Notification.job_bytes_downloaded', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_bytes_staged', full_name='CDataPublisher_ClientUpdateAppJob_Notification.job_bytes_staged', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_comitted', full_name='CDataPublisher_ClientUpdateAppJob_Notification.bytes_comitted', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_app_state', full_name='CDataPublisher_ClientUpdateAppJob_Notification.start_app_state', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_machine_id', full_name='CDataPublisher_ClientUpdateAppJob_Notification.stats_machine_id', index=11,
      number=12, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branch_name', full_name='CDataPublisher_ClientUpdateAppJob_Notification.branch_name', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_bytes_downloaded', full_name='CDataPublisher_ClientUpdateAppJob_Notification.total_bytes_downloaded', index=13,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_bytes_staged', full_name='CDataPublisher_ClientUpdateAppJob_Notification.total_bytes_staged', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_bytes_restored', full_name='CDataPublisher_ClientUpdateAppJob_Notification.total_bytes_restored', index=15,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_borrowed', full_name='CDataPublisher_ClientUpdateAppJob_Notification.is_borrowed', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_free_weekend', full_name='CDataPublisher_ClientUpdateAppJob_Notification.is_free_weekend', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_bytes_legacy', full_name='CDataPublisher_ClientUpdateAppJob_Notification.total_bytes_legacy', index=18,
      number=19, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_bytes_patched', full_name='CDataPublisher_ClientUpdateAppJob_Notification.total_bytes_patched', index=19,
      number=20, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_bytes_saved', full_name='CDataPublisher_ClientUpdateAppJob_Notification.total_bytes_saved', index=20,
      number=21, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CDataPublisher_ClientUpdateAppJob_Notification.cell_id', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=610,
  serialized_end=1202,
)


_CVALVEHWSURVEY_GETSURVEYSCHEDULE_REQUEST = _descriptor.Descriptor(
  name='CValveHWSurvey_GetSurveySchedule_Request',
  full_name='CValveHWSurvey_GetSurveySchedule_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='surveydatetoken', full_name='CValveHWSurvey_GetSurveySchedule_Request.surveydatetoken', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='surveydatetokenversion', full_name='CValveHWSurvey_GetSurveySchedule_Request.surveydatetokenversion', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1204,
  serialized_end=1303,
)


_CVALVEHWSURVEY_GETSURVEYSCHEDULE_RESPONSE = _descriptor.Descriptor(
  name='CValveHWSurvey_GetSurveySchedule_Response',
  full_name='CValveHWSurvey_GetSurveySchedule_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='surveydatetoken', full_name='CValveHWSurvey_GetSurveySchedule_Response.surveydatetoken', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='surveydatetokenversion', full_name='CValveHWSurvey_GetSurveySchedule_Response.surveydatetokenversion', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1305,
  serialized_end=1405,
)

DESCRIPTOR.message_types_by_name['CDataPublisher_ClientContentCorruptionReport_Notification'] = _CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION
DESCRIPTOR.message_types_by_name['CDataPublisher_ClientUpdateAppJob_Notification'] = _CDATAPUBLISHER_CLIENTUPDATEAPPJOB_NOTIFICATION
DESCRIPTOR.message_types_by_name['CValveHWSurvey_GetSurveySchedule_Request'] = _CVALVEHWSURVEY_GETSURVEYSCHEDULE_REQUEST
DESCRIPTOR.message_types_by_name['CValveHWSurvey_GetSurveySchedule_Response'] = _CVALVEHWSURVEY_GETSURVEYSCHEDULE_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CDataPublisher_ClientContentCorruptionReport_Notification = _reflection.GeneratedProtocolMessageType('CDataPublisher_ClientContentCorruptionReport_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION,
  '__module__' : 'steammessages_datapublisher_pb2'
  # @@protoc_insertion_point(class_scope:CDataPublisher_ClientContentCorruptionReport_Notification)
  })
_sym_db.RegisterMessage(CDataPublisher_ClientContentCorruptionReport_Notification)

CDataPublisher_ClientUpdateAppJob_Notification = _reflection.GeneratedProtocolMessageType('CDataPublisher_ClientUpdateAppJob_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CDATAPUBLISHER_CLIENTUPDATEAPPJOB_NOTIFICATION,
  '__module__' : 'steammessages_datapublisher_pb2'
  # @@protoc_insertion_point(class_scope:CDataPublisher_ClientUpdateAppJob_Notification)
  })
_sym_db.RegisterMessage(CDataPublisher_ClientUpdateAppJob_Notification)

CValveHWSurvey_GetSurveySchedule_Request = _reflection.GeneratedProtocolMessageType('CValveHWSurvey_GetSurveySchedule_Request', (_message.Message,), {
  'DESCRIPTOR' : _CVALVEHWSURVEY_GETSURVEYSCHEDULE_REQUEST,
  '__module__' : 'steammessages_datapublisher_pb2'
  # @@protoc_insertion_point(class_scope:CValveHWSurvey_GetSurveySchedule_Request)
  })
_sym_db.RegisterMessage(CValveHWSurvey_GetSurveySchedule_Request)

CValveHWSurvey_GetSurveySchedule_Response = _reflection.GeneratedProtocolMessageType('CValveHWSurvey_GetSurveySchedule_Response', (_message.Message,), {
  'DESCRIPTOR' : _CVALVEHWSURVEY_GETSURVEYSCHEDULE_RESPONSE,
  '__module__' : 'steammessages_datapublisher_pb2'
  # @@protoc_insertion_point(class_scope:CValveHWSurvey_GetSurveySchedule_Response)
  })
_sym_db.RegisterMessage(CValveHWSurvey_GetSurveySchedule_Response)


DESCRIPTOR._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['download_source']._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['objectid']._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['cellid']._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['is_manifest']._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['object_size']._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['corruption_type']._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['used_https']._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['oc_proxy_detected']._options = None

_DATAPUBLISHER = _descriptor.ServiceDescriptor(
  name='DataPublisher',
  full_name='DataPublisher',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030#Data Publisher (DP) server services',
  create_key=_descriptor._internal_create_key,
  serialized_start=1408,
  serialized_end=1660,
  methods=[
  _descriptor.MethodDescriptor(
    name='ClientContentCorruptionReport',
    full_name='DataPublisher.ClientContentCorruptionReport',
    index=0,
    containing_service=None,
    input_type=_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClientUpdateAppJobReport',
    full_name='DataPublisher.ClientUpdateAppJobReport',
    index=1,
    containing_service=None,
    input_type=_CDATAPUBLISHER_CLIENTUPDATEAPPJOB_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAPUBLISHER)

DESCRIPTOR.services_by_name['DataPublisher'] = _DATAPUBLISHER


_VALVEHWSURVEY = _descriptor.ServiceDescriptor(
  name='ValveHWSurvey',
  full_name='ValveHWSurvey',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\202\265\030\rValveHWSurvey',
  create_key=_descriptor._internal_create_key,
  serialized_start=1663,
  serialized_end=1835,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetSurveySchedule',
    full_name='ValveHWSurvey.GetSurveySchedule',
    index=0,
    containing_service=None,
    input_type=_CVALVEHWSURVEY_GETSURVEYSCHEDULE_REQUEST,
    output_type=_CVALVEHWSURVEY_GETSURVEYSCHEDULE_RESPONSE,
    serialized_options=b'\202\265\030\027Should I run the survey',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VALVEHWSURVEY)

DESCRIPTOR.services_by_name['ValveHWSurvey'] = _VALVEHWSURVEY

DataPublisher = service_reflection.GeneratedServiceType('DataPublisher', (_service.Service,), dict(
  DESCRIPTOR = _DATAPUBLISHER,
  __module__ = 'steammessages_datapublisher_pb2'
  ))

DataPublisher_Stub = service_reflection.GeneratedServiceStubType('DataPublisher_Stub', (DataPublisher,), dict(
  DESCRIPTOR = _DATAPUBLISHER,
  __module__ = 'steammessages_datapublisher_pb2'
  ))


ValveHWSurvey = service_reflection.GeneratedServiceType('ValveHWSurvey', (_service.Service,), dict(
  DESCRIPTOR = _VALVEHWSURVEY,
  __module__ = 'steammessages_datapublisher_pb2'
  ))

ValveHWSurvey_Stub = service_reflection.GeneratedServiceStubType('ValveHWSurvey_Stub', (ValveHWSurvey,), dict(
  DESCRIPTOR = _VALVEHWSURVEY,
  __module__ = 'steammessages_datapublisher_pb2'
  ))


# @@protoc_insertion_point(module_scope)
